@@ -2,11 +2,12 @@
 from django.conf.urls import url
 from django.core.paginator import Paginator
 from django.shortcuts import get_object_or_404
-from django import http
 
+from . import auth
+from . import http
 from . import engine
 
-class Publisher(engine.JsonEngine):
+class BasePublisher(auth.NullAuthorise):
 
     def __init__(self, request, *args, **kwargs):
         self.request = request
@@ -73,19 +74,29 @@ class Publisher(engine.JsonEngine):
         # See if there's a method agnostic handler
         if handler is None:
             raise http.Http404
+        # Permission check
+        if not self.may(request, action, object_id, **kwargs):
+            return http.HttpResponseUnauthorized()
         # Do we need to pass any of this?
         return handler(request, action=action, object_id=object_id, **kwargs)
 
+class Publisher(engine.JsonEngine, BasePublisher):
+    '''Default API-style publisher'''
+
     def get_serialiser(self):
+        '''Return the serialiser instance to use for this request'''
         return self.serialiser
 
     def get_object_list(self):
+        '''Return the object list appropriate for this request'''
         raise NotImplementedError
 
     def get_object(self, object_id):
+        '''Return the object for the given id'''
         raise NotImplementedError
 
     def get_page(self, object_list):
+        '''Return a paginated object list, along with some metadata'''
         page_size = getattr(self, 'page_size', None)
         if not page_size:
             return {
@@ -117,45 +128,40 @@ class Publisher(engine.JsonEngine):
             return self.request.GET
         return self.request.POST
 
-    def list_get_default(self, request, **kwargs):
-        object_list = self.get_object_list()
-        serialiser = self.get_serialiser()
-        data = self.get_page(object_list)
-        data['objects'] = serialiser.deflate_list(data['objects'], publisher=self)
-        return self.create_response(data)
-
-    def list_post_default(self, request, object_id=None, **kwargs):
-        '''Default list POST handler -- create object'''
-
-    def object_get_default(self, request, object_id, **kwargs):
-        '''Default object GET handler -- get object'''
-        obj = self.get_object(object_id)
-        serialiser = self.get_serialiser()
-        return self.render_single_object(obj, serialiser)
-
-    def object_put_default(self, request, object_id, **kwargs):
-        '''Default object PUT handler -- update object'''
-        obj = self.get_object(object_id)
-        serialiser = self.get_serialiser()
-        obj = serialiser.inflate_object(self.get_data(), obj)
-        return self.render_single_object(obj, serialiser)
-
     def render_single_object(self, obj, serialiser=None, **response_kwargs):
+        '''Helper to return a single object instance serialised.'''
         if serialiser is None:
             serialiser = self.get_serialiser()
         data = serialiser.deflate_object(obj, publisher=self)
         return self.create_response(data, **response_kwargs)
 
     def create_response(self, content, **response_kwargs):
+        '''Return a response, serialising the content'''
         response_class = response_kwargs.pop('response_class', http.HttpResponse)
         response_kwargs.setdefault('content_type', self.CONTENT_TYPES[0])
         return response_class(self.dumps(content), **response_kwargs)
 
+    def list_get_default(self, request, **kwargs):
+        object_list = self.get_object_list()
+        data = self.get_page(object_list)
+
+        serialiser = self.get_serialiser()
+        data['objects'] = serialiser.deflate_list(data['objects'], publisher=self)
+        return self.create_response(data)
+
+    def object_get_default(self, request, object_id, **kwargs):
+        '''Default object GET handler -- get object'''
+        obj = self.get_object(object_id)
+        return self.render_single_object(obj)
+
 
 class ModelPublisher(Publisher):
+    '''A Publisher with useful methods to publish Models'''
+
     @property
     def model(self):
-        '''By default, we try to get the model from out serialiser'''
+        '''By default, we try to get the model from our serialiser'''
+        # XXX Should this call get_serialiser?
         return self.serialiser._meta.model
 
     # Auto-build serialiser from model class?
@@ -166,3 +172,69 @@ class ModelPublisher(Publisher):
     def get_object(self, object_id):
         return get_object_or_404(self.get_object_list(), pk=object_id)
 
+
+class ModelFormMixin(object):
+    '''Provide writable models using form validation'''
+
+    initial = {}
+    form_class = None
+
+    # Here we mimic the FormMixin from django
+    def get_initial(self):
+        """
+        Returns the initial data to use for forms on this view.
+        """
+        return self.initial.copy()
+
+    def get_form_class(self):
+        """
+        Returns the form class to use in this view
+        """
+        return self.form_class
+
+    def get_form(self, form_class):
+        """
+        Returns an instance of the form to be used in this view.
+        """
+        return form_class(**self.get_form_kwargs())
+
+    def get_form_kwargs(self, **kwargs):
+        """
+        Returns the keyword arguments for instantiating the form.
+        """
+        kwargs.setdefault('initial', self.get_initial())
+        if self.request.method in ('POST', 'PUT'):
+            kwargs.update({
+                'data': self.request.POST,
+                'files': self.request.FILES,
+            })
+        return kwargs
+
+    def list_post_default(self, request, *args, **kwargs):
+        form_class = self.get_form_class()
+        form = self.get_form(form_class)
+
+        if form.is_valid():
+            obj = form.save()
+            return self.render_single_object(obj)
+
+        # return errors
+
+
+    def object_put_default(self, request, object_id, *args, **kwargs):
+        obj = self.get_object(object_id)
+        form_class = self.get_form_class()
+        form = self.get_form(form_class, instance=obj)
+
+        if form.is_valid():
+            obj = form.save()
+            return self.render_single_object(obj)
+
+        # return errors
+
+    def object_delete_default(self, request, object_id, *args, **kwargs):
+        obj = self.get_object(object_id)
+        # XXX Some sort of verification?
+        obj.delete()
+        return http.HttpResponseNoContent()
+
